

!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!                                          numgeo
!                              Copyright (C) 2017 Jan Machacek
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!
! SUBROUTINE: user_contact_properties
!
!> author: Patrick Staubach, patrick.staubach@yahoo.de
!> date: 28.04.2020
!
!> Interface to user subroutine to define contact model properties 
!
!>### History
!> 28.04.2020, P. Staubach - Initial version
!> 29.06.2020, P. Staubach - Added arguments to subroutine
!
!>@todo
!> After program is completed, this subroutine should be excluded again and made accessible to the
!> main program numgeo.exe as a dynamic linked library (*.so). This should be done to prevent excessive 
!> recompilation before every calculation with changed initial conditions.
!>@endtodo
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
subroutine user_contact_properties(istep,node,slave,nprops,interaction_type,step_time,coords,   &
                                   coords_connected,disp,disp_connected,props) bind(c,name='user_contact_properties')
  use, intrinsic :: iso_c_binding
  implicit none
  integer(c_int)                    , intent(in)    :: istep               !! step number
  integer(c_int)                    , intent(in)    :: node                !! node label
  logical                           , intent(in)    :: slave               !! true if current node belongs to slave surface
  integer(c_int)                    , intent(in)    :: nprops              !! number of contact properties
  character(c_char)                 , intent(in)    :: interaction_type(*) !! constitutive contact name
  real(c_double)                    , intent(in)    :: step_time           !! current step time cdb%step(istep)%time%is
  real(c_double), dimension(3)      , intent(in)    :: coords              !! reference coordinates of the contact point
  real(c_double), dimension(3)      , intent(in)    :: coords_connected    !! reference coordinates of the connected contact point
  real(c_double), dimension(3)      , intent(in)    :: disp                !! displacement of the contact point
  real(c_double), dimension(3)      , intent(in)    :: disp_connected      !! displacement of the connected contact point
  real(c_double), dimension(nprops) , intent(inout) :: props               !! properties of this contact

  props(:) = 0.0d0
  props(1) = 3d3
  if(slave .eqv. .false.) then
    if(coords(2)  + disp(2)  > 0.641 + disp(2) .and. coords(2) < 0.8138 - disp(2) ) then
      props(2) = 0.194d0
    endif
  else
    if(coords_connected(2)+ disp_connected(2) > 0.641 + disp_connected(2)) then
      props(2) = 0.194d0
    endif
  endif
  
end subroutine user_contact_properties


