!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!                                          numgeo
!                Copyright (C) 2018-2024 Jan Machacek, Patrick Staubach
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!
! SUBROUTINE: user_initial_state_variables
!
!> author: Jan Machacek, jan-machacek@outlook.com
!> date: 30.03.2019
!
!> Interface to user subroutine to define the initial values for arbitrary state variables (statev)
!
!>### History
!> 30.03.2019, Jan Machacek - Initial version
!
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
subroutine user_initial_state_variables(ie,igp,ndim,nstatev,nchar,material,coords,statev)   &
  bind(c,name='user_initial_state_variables')
  use, intrinsic :: iso_c_binding
  implicit none
  integer(c_int)                    , intent(in)    :: ie           !! element label
  integer(c_int)                    , intent(in)    :: igp          !! integration point label
  integer(c_int)                    , intent(in)    :: ndim         !! number of active dimensions
  integer(c_int)                    , intent(in)    :: nstatev      !! number of stress components
  integer(c_int)                    , intent(in)    :: nchar        !! length of the material name
  character(c_char)                 , intent(in)    :: material(*)  !! material name
  real(c_double), dimension(3)      , intent(in)    :: coords       !! coordinates of the integration point
  real(c_double), dimension(nstatev), intent(inout) :: statev       !! initial statev

  real(c_double) :: h_top, void0, K0,  surface_load, n, gamma_tot, pw, stress, trT, hs, n_hyp

  statev(:) = 0.0d0

  h_top = 0.81d0
  void0 = 0.637d0
  K0 = 1.0d0-sin(0.577d0)
  hs = 19000000.0d0
  n_hyp = 0.285

  ! external load on top surface
  surface_load = 0.1d0
  

  ! total unit weight
  n = void0 / (1.0d0 + void0)
  gamma_tot = ((1.0d0-n)*2.65d0+n) * 10.0d0

  ! pore water pressure
  pw = (h_top-coords(2)) * 10.0d0

  ! stress (vertical and mean effective stress)
  stress = gamma_tot * (h_top-coords(2)) + surface_load - pw
  trT    = (1.0d0+2.0d0*K0) * stress / 3.0d0
  
  statev(1) =  void0 *exp(-(trT/hs)**n_hyp)

  statev(1+2) =  -0.00005 

end subroutine user_initial_state_variables
