!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!                                          numgeo
!                Copyright (C) 2018-2023 Jan Machacek, Patrick Staubach
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
!
! SUBROUTINE: user_contact_properties
!
!> author: Patrick Staubach, patrick.staubach@yahoo.de
!> date: 28.04.2020
!
!> Interface to user subroutine to define contact model properties 
!
!>### History
!> 28.04.2020, P. Staubach - Initial version
!> 29.06.2020, P. Staubach - Added arguments to subroutine
!> 05.07.2023, P. Staubach - Windows version
!
!=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~~=~=~
subroutine user_contact_properties(istep,node,slave,nprops,interaction_type,step_time,coords,   &
                                   coords_connected,disp,disp_connected,props) 
  implicit none
    !DEC$ ATTRIBUTES DLLEXPORT, STDCALL, REFERENCE :: user_contact_properties
  integer                    , intent(in)    :: istep               !! step number
  integer                    , intent(in)    :: node                !! node label
  logical                    , intent(in)    :: slave               !! true if current node belongs to slave surface
  integer                    , intent(in)    :: nprops              !! number of contact properties
  character                  , intent(in)    :: interaction_type(*) !! constitutive contact name
  real(8)                    , intent(in)    :: step_time           !! current step time cdb%step(istep)%time%is
  real(8), dimension(3)      , intent(in)    :: coords              !! reference coordinates of the contact point
  real(8), dimension(3)      , intent(in)    :: coords_connected    !! reference coordinates of the connected contact point
  real(8), dimension(3)      , intent(in)    :: disp                !! displacement of the contact point
  real(8), dimension(3)      , intent(in)    :: disp_connected      !! displacement of the connected contact point
  real(8), dimension(nprops) , intent(inout) :: props               !! properties of this contact
  ! user coding to define the contact properties props
  !write(*,*) 'WARNING: user_initial_stress is called without user coding'
  props(:) = 0.0d0
  props(1) = 3d3
  if(slave .eqv. .false.) then
    if(coords(2)  + disp(2)  > 0.641 + disp(2) .and. coords(2) < 0.8138 - disp(2) ) then
      props(2) = 0.194d0
    endif
  else
    if(coords_connected(2)+ disp_connected(2) > 0.641 + disp_connected(2)) then
      props(2) = 0.194d0
    endif
  endif
  
end subroutine user_contact_properties


